@@ -56,7 +56,6 @@ class SwidgetDevice:
 
     async def message_callback(self, message):
         """Entrypoint for a websocket callback"""
-        _LOGGER.error("Processing message: %s", message)
         if message["request_id"] == "summary":
             await self.process_summary(message)
         elif message["request_id"] == "state" or message["request_id"] == "DYNAMIC_UPDATE" or message["request_id"] == "command":
@@ -102,11 +101,7 @@ class SwidgetDevice:
             pass
 
         for assembly in self.assemblies:
-            _LOGGER.error(f"Processing assembly: {assembly}")
             for id, component in self.assemblies[assembly].components.items():
-                if id == "0":
-                    continue
-                _LOGGER.error(f"id: {id} comp: {component}")
                 try:
                     component.functions.update(state[assembly]["components"][id])
                 except:
